# TableModel

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Unique identifier for the table | 
**primary_field_id** | **str** | The first column in the table and every view | 
**name** | **str** | Name of the table | 
**description** | **str** | Optional description of the table | [optional] 
**fields** | [**list[FieldConfigResponse]**](FieldConfigResponse.md) | Array of field definitions | 
**views** | [**list[TableModelViews]**](TableModelViews.md) | Array of view configurations | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

